pub enum StaticTransformOptimizations {
Enabled,
Disabled,
}Expand description
Configure the behavior of static scene optimizations for Transform propagation.
For scenes with many static entities, it is much faster to track trees of unchanged
Transforms and skip these during the expensive transform propagation step. If your scene is
very dynamic, the cost of tracking these trees can exceed the performance benefits. By default,
static scene optimization is enabled.
Variants
Implementations
Sourceimpl StaticTransformOptimizations
impl StaticTransformOptimizations
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Returns true if static scene optimizations are enabled.