pub struct RectLight {
pub color: Color,
pub intensity: f32,
pub range: f32,
pub width: f32,
pub height: f32,
}Expand description
A rectangular area light.
The rectangle lies in the XY plane of the entity’s local coordinate frame and faces the local -Z direction.
Shadow maps are currently unsupported, objects illuminated by a
RectLight will not cast shadows.
Note: Requires the area_light_luts cargo feature.
Fields
color: ColorThe color of the light.
By default, this is white.
intensity: f32Luminous power in lumens, representing the amount of light emitted by this source in all directions.
range: f32Cut-off for the light’s area-of-effect. Fragments outside this range will not be affected by
this light at all, so it’s important to tune this together with intensity to prevent hard
lighting cut-offs.
width: f32Width of the light rectangle (along local X).
height: f32Height of the light rectangle (along local Y).