pub struct ViewFrustum {
pub half_spaces: [HalfSpace; 6],
}Expand description
A region of 3D space defined by the intersection of 6 HalfSpaces.
View Frustums are typically an apex-truncated square pyramid (a pyramid without the top) or a cuboid.
Half spaces are ordered left, right, top, bottom, near, far. The normal vectors of the half-spaces point towards the interior of the frustum.
Fields
half_spaces: [HalfSpace; 6]The six half-spaces making up the frustum
Implementations
Sourceimpl ViewFrustum
impl ViewFrustum
Sourcepub const NEAR_PLANE_IDX: usize = 4
pub const NEAR_PLANE_IDX: usize = 4
The index for the near plane in half_spaces
Sourcepub const FAR_PLANE_IDX: usize = 5
pub const FAR_PLANE_IDX: usize = 5
The index for the far plane in half_spaces
Sourcepub fn from_clip_from_world(clip_from_world: &Mat4) -> ViewFrustum
pub fn from_clip_from_world(clip_from_world: &Mat4) -> ViewFrustum
Returns a view frustum derived from clip_from_world.
Sourcepub fn from_clip_from_world_custom_far(
clip_from_world: &Mat4,
view_translation: &Vec3,
view_backward: &Vec3,
far: f32,
) -> ViewFrustum
pub fn from_clip_from_world_custom_far( clip_from_world: &Mat4, view_translation: &Vec3, view_backward: &Vec3, far: f32, ) -> ViewFrustum
Returns a view frustum derived from clip_from_world,
but with a custom far plane.
Sourcepub fn corners(&self) -> Option<[Vec3; 8]>
pub fn corners(&self) -> Option<[Vec3; 8]>
Calculates the corners of this frustum. Returns None if the frustum isn’t properly defined.
If Some, the corners are returned in the following order:
near top left, near top right, near bottom right, near bottom left,
far top left, far top right, far bottom right, far bottom left.
If the far plane is an inactive half space, the intersection points
that include the far plane will be Vec3::NAN.