pub struct Enter {
pub hit: HitData,
pub is_in_bounds: bool,
}Expand description
Fires when a pointer crosses into the bounds of a target entity.
Unlike Over, this event bubbles up through a subset of the
target entity’s ancestors
(traversed via the ChildOf relationship).
Event Propagation
An ancestor of a target entity will receive an Enter event
when the ancestor does not have a direct relation to any entity hovered by the
pointer in the previous frame. For example, for a given pointer:
If the previously hovered entity C has the following entity ancestry: A -> B -> C
And the currently hovered entity E has the following entity ancestry: A -> D -> E
Enter events would be sent for both E and its direct ancestor D.
An Enter event would not be sent for A because it is a shared ancestor of both C and E.
Note: An Enter event may be fired for an ancestor even if the pointer does not enter
within the ancestor’s bounds. More concretely, if a child’s bounds extend beyond the parent’s
and the pointer enters the child’s bounds without crossing into the parent’s,
two Enter events are still emitted for both the child and the parent.
This matches the triggering behavior of mouseenter events on the web.
To find out whether a pointer is within the target entity’s bounds
immediately upon entering, check the value of is_in_bounds.
Refer to pointer_events for more information on how these events are triggered.
Fields
hit: HitDataInformation about the picking intersection.
is_in_bounds: boolWhether this pointer directly entered into the target entity’s bounds at the time of the event. This may be false if this entity’s child’s bounds extended beyond the entity and the pointer entered within the child’s bounds only.